@@ -21,31 +21,34 @@ __all__ = ('DataMappingError', 'StreamFile', 'LocalFile', 'BaseTelegram',
            'InlineKeyboardMarkup', 'InlineKeyboardButton', 'LoginUrl',
            'CallbackQuery', 'ForceReply', 'ChatPhoto', 'ChatInviteLink',
            'ChatMember', 'ChatMemberUpdated', 'ChatPermissions',
-           'ChatLocation', 'BotCommand', 'InputFile', 'InputMedia',
-           'InputMediaPhoto', 'InputMediaVideo', 'InputMediaAnimation',
-           'InputMediaAudio', 'InputMediaDocument', 'Sticker', 'StickerSet',
-           'MaskPosition', 'InlineQuery', 'InlineQueryResult',
-           'InlineQueryResultArticle', 'InlineQueryResultPhoto',
-           'InlineQueryResultGif', 'InlineQueryResultMpeg4Gif',
-           'InlineQueryResultVideo', 'InlineQueryResultAudio',
-           'InlineQueryResultVoice', 'InlineQueryResultDocument',
-           'InlineQueryResultLocation', 'InlineQueryResultVenue',
-           'InlineQueryResultContact', 'InlineQueryResultGame',
-           'InlineQueryResultCachedPhoto', 'InlineQueryResultCachedGif',
-           'InlineQueryResultCachedMpeg4Gif', 'InlineQueryResultCachedSticker',
-           'InlineQueryResultCachedDocument', 'InlineQueryResultCachedVideo',
-           'InlineQueryResultCachedVoice', 'InlineQueryResultCachedAudio',
-           'InputMessageContent', 'InputTextMessageContent',
-           'InputLocationMessageContent', 'InputVenueMessageContent',
-           'InputContactMessageContent', 'ChosenInlineResult', 'LabeledPrice',
-           'Invoice', 'ShippingAddress', 'OrderInfo', 'ShippingOption',
-           'SuccessfulPayment', 'ShippingQuery', 'PreCheckoutQuery',
-           'PassportData', 'PassportFile', 'EncryptedPassportElement',
-           'EncryptedCredentials', 'PassportElementError',
-           'PassportElementErrorDataField', 'PassportElementErrorFrontSide',
-           'PassportElementErrorReverseSide', 'PassportElementErrorSelfie',
-           'PassportElementErrorFile', 'PassportElementErrorFiles',
-           'PassportElementErrorTranslationFile',
+           'ChatLocation', 'BotCommand', 'BotCommandScopeDefault',
+           'BotCommandScopeAllPrivateChats', 'BotCommandScopeAllGroupChats',
+           'BotCommandScopeChatAdministrators', 'BotCommandScopeChat',
+           'BotCommandScopeAllChatAdministrators', 'BotCommandScopeChatMember',
+           'InputFile', 'BotCommandScope', 'InputMedia', 'InputMediaPhoto',
+           'InputMediaVideo', 'InputMediaAnimation', 'InputMediaAudio',
+           'InputMediaDocument', 'Sticker', 'StickerSet', 'MaskPosition',
+           'InlineQuery', 'InlineQueryResult', 'InlineQueryResultArticle',
+           'InlineQueryResultPhoto', 'InlineQueryResultGif',
+           'InlineQueryResultMpeg4Gif', 'InlineQueryResultVideo',
+           'InlineQueryResultAudio', 'InlineQueryResultVoice',
+           'InlineQueryResultDocument', 'InlineQueryResultLocation',
+           'InlineQueryResultVenue', 'InlineQueryResultContact',
+           'InlineQueryResultGame', 'InlineQueryResultCachedPhoto',
+           'InlineQueryResultCachedGif', 'InlineQueryResultCachedMpeg4Gif',
+           'InlineQueryResultCachedSticker', 'InlineQueryResultCachedDocument',
+           'InlineQueryResultCachedVideo', 'InlineQueryResultCachedVoice',
+           'InlineQueryResultCachedAudio', 'InputMessageContent',
+           'InputTextMessageContent', 'InputLocationMessageContent',
+           'InputVenueMessageContent', 'InputContactMessageContent',
+           'ChosenInlineResult', 'LabeledPrice', 'Invoice', 'ShippingAddress',
+           'OrderInfo', 'ShippingOption', 'SuccessfulPayment', 'ShippingQuery',
+           'PreCheckoutQuery', 'PassportData', 'PassportFile',
+           'EncryptedPassportElement', 'EncryptedCredentials',
+           'PassportElementError', 'PassportElementErrorDataField',
+           'PassportElementErrorFrontSide', 'PassportElementErrorReverseSide',
+           'PassportElementErrorSelfie', 'PassportElementErrorFile',
+           'PassportElementErrorFiles', 'PassportElementErrorTranslationFile',
            'PassportElementErrorTranslationFiles',
            'PassportElementErrorUnspecified', 'Game', 'CallbackGame',
            'GameHighScore')
@@ -270,6 +273,7 @@ class Update(BaseTelegram):
     poll_answer: Optional['PollAnswer'] = None
     my_chat_member: Optional['ChatMemberUpdated'] = None
     chat_member: Optional['ChatMemberUpdated'] = None
+    chat_join_request: Optional['ChatJoinRequest'] = None
 
 
 @attr.s(auto_attribs=True)
@@ -307,11 +311,13 @@ class Chat(BaseTelegram):
     last_name: Optional[str] = None
     photo: Optional['ChatPhoto'] = None
     bio: Optional[str] = None
+    has_private_forwards: Optional[bool] = None
     description: Optional[str] = None
     invite_link: Optional[str] = None
     pinned_message: Optional['Message'] = None
     permissions: Optional['ChatPermissions'] = None
     slow_mode_delay: Optional[int] = None
+    has_protected_content: Optional[bool] = None
     sticker_set_name: Optional[str] = None
     can_set_sticker_set: Optional[bool] = None
     linked_chat_id: Optional[int] = None
@@ -331,9 +337,11 @@ class Message(BaseTelegram):
     forward_signature: Optional[str] = None
     forward_sender_name: Optional[str] = None
     forward_date: Optional[int] = None
+    is_automatic_forward: Optional[bool] = None
     reply_to_message: Optional['Message'] = None
     via_bot: Optional[User] = None
     edit_date: Optional[int] = None
+    has_protected_content: Optional[bool] = None
     media_group_id: Optional[str] = None
     author_signature: Optional[str] = None
     text: Optional[str] = None
@@ -596,6 +604,7 @@ class ReplyKeyboardMarkup(BaseTelegram):
     keyboard: List[List['KeyboardButton']]
     resize_keyboard: Optional[bool] = None
     one_time_keyboard: Optional[bool] = None
+    input_field_placeholder: Optional[str] = None
     selective: Optional[bool] = None
 
 
@@ -657,6 +666,7 @@ class CallbackQuery(BaseTelegram):
 @attr.s(auto_attribs=True)
 class ForceReply(BaseTelegram):
     force_reply: bool
+    input_field_placeholder: Optional[str] = None
     selective: Optional[bool] = None
 
 
@@ -672,10 +682,13 @@ class ChatPhoto(BaseTelegram):
 class ChatInviteLink(BaseTelegram):
     invite_link: str
     creator: User
+    creates_join_request: bool
     is_primary: bool
     is_revoked: bool
+    name: Optional[str] = None
     expire_date: Optional[int] = None
     member_limit: Optional[int] = None
+    pending_join_request_count: Optional[int] = None
 
 
 @attr.s(auto_attribs=True)
@@ -714,6 +727,15 @@ class ChatMemberUpdated(BaseTelegram):
     invite_link: Optional[ChatInviteLink] = None
 
 
+@attr.s(auto_attribs=True)
+class ChatJoinRequest(BaseTelegram):
+    chat: Chat
+    from_: User
+    date: int
+    bio: Optional[str] = None
+    invite_link: Optional[ChatInviteLink] = None
+
+
 @attr.s(auto_attribs=True)
 class ChatPermissions(BaseTelegram):
     can_send_messages: Optional[bool] = None
@@ -738,6 +760,53 @@ class BotCommand(BaseTelegram):
     description: str
 
 
+@attr.s(auto_attribs=True)
+class BotCommandScopeDefault(BaseTelegram):
+    type: str = 'default'
+
+
+@attr.s(auto_attribs=True)
+class BotCommandScopeAllPrivateChats(BaseTelegram):
+    type: str = 'all_private_chats'
+
+
+@attr.s(auto_attribs=True)
+class BotCommandScopeAllGroupChats(BaseTelegram):
+    type: str = 'all_group_chats'
+
+
+@attr.s(auto_attribs=True)
+class BotCommandScopeAllChatAdministrators(BaseTelegram):
+    type: str = 'all_chat_administrators'
+
+
+@attr.s(auto_attribs=True)
+class BotCommandScopeChat(BaseTelegram):
+    chat_id: Union[int, str]
+    type: str = 'chat'
+
+
+@attr.s(auto_attribs=True)
+class BotCommandScopeChatAdministrators(BaseTelegram):
+    chat_id: Union[int, str]
+    type: str = 'chat'
+
+
+@attr.s(auto_attribs=True)
+class BotCommandScopeChatMember(BaseTelegram):
+    chat_id: Union[int, str]
+    user_id: int
+    type: str = 'chat'
+
+
+BotCommandScope = Union[BotCommandScopeDefault,
+                        BotCommandScopeAllPrivateChats,
+                        BotCommandScopeAllGroupChats,
+                        BotCommandScopeAllChatAdministrators,
+                        BotCommandScopeChat,
+                        BotCommandScopeChatAdministrators,
+                        BotCommandScopeChatMember]
+
 InputFile = Union[LocalFile, StreamFile]
 
 
@@ -802,6 +871,7 @@ class Sticker(BaseTelegram):
     width: int
     height: int
     is_animated: bool
+    is_video: bool
     thumb: Optional[PhotoSize] = None
     emoji: Optional[str] = None
     set_name: Optional[str] = None
@@ -814,6 +884,7 @@ class StickerSet(BaseTelegram):
     name: str
     title: str
     is_animated: bool
+    is_video: bool
     contains_masks: bool
     stickers: Tuple[Sticker, ...]
     thumb: Optional[PhotoSize] = None
